@@ -26,7 +26,7 @@ sys.modules['ccxt'] = ccxt_module
 
 # ----------------------------------------------------------------------------
 
-__version__ = '4.4.82'
+__version__ = '4.4.85'
 
 # ----------------------------------------------------------------------------
 
@@ -88,8 +88,9 @@ from ccxt.base.errors import UnsubscribeError                         # noqa: F4
 from ccxt.base.errors import error_hierarchy                          # noqa: F401
 
 from ccxt.bitmex import bitmex                                        # noqa: F401
+from ccxt.kuna import kuna                                            # noqa: F401
 
-exchanges = [    'bitmex',]
+exchanges = [    'bitmex',    'kuna',]
 
 base = [
     'Exchange',
