@@ -8,7 +8,7 @@ sys.modules['ccxt'] = ccxt_module
 
 # -----------------------------------------------------------------------------
 
-__version__ = '4.4.82'
+__version__ = '4.4.85'
 
 # -----------------------------------------------------------------------------
 
@@ -68,8 +68,9 @@ from ccxt.base.errors import error_hierarchy                          # noqa: F4
 
 
 from ccxt.async_support.bitmex import bitmex                                    # noqa: F401
+from ccxt.async_support.kuna import kuna                                        # noqa: F401
 
-exchanges = [    'bitmex',]
+exchanges = [    'bitmex',    'kuna',]
 
 base = [
     'Exchange',
